@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2004 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -26,7 +26,6 @@ namespace Tellico {
  * @li Title
  *
  * @author Robby Stephenson
- * @version $Id: cardcollection.h 70 2003-07-31 03:49:14Z robby $
  */
 class CardCollection : public Collection {
 Q_OBJECT
@@ -42,7 +41,7 @@ public:
 
   virtual Type type() const { return Card; }
 
-  static FieldList defaultFields();
+  static FieldVec defaultFields();
 };
 
   } // end namespace
