@@ -48,7 +48,7 @@ public:
   virtual Data::EntryPtr fetchEntry(uint uid);
   virtual Type type() const { return AnimeNfo; }
   virtual bool canFetch(int type) const;
-  virtual void readConfigHook(KConfig* config, const QString& group);
+  virtual void readConfigHook(const KConfigGroup& config);
 
   virtual void updateEntry(Data::EntryPtr entry);
 
@@ -57,7 +57,7 @@ public:
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
     ConfigWidget(QWidget* parent_);
-    virtual void saveConfig(KConfig*) {}
+    virtual void saveConfig(KConfigGroup&) {}
     virtual QString preferredName() const;
   };
   friend class ConfigWidget;
