@@ -14,9 +14,10 @@
 #ifndef PARAFIELDWIDGET_H
 #define PARAFIELDWIDGET_H
 
-class QTextEdit;
-
 #include "fieldwidget.h"
+#include "../datavectors.h"
+
+class KTextEdit;
 
 namespace Tellico {
   namespace GUI {
@@ -41,7 +42,7 @@ protected:
   virtual QWidget* widget();
 
 private:
-  QTextEdit* m_textEdit;
+  KTextEdit* m_textEdit;
 };
 
   } // end GUI namespace
